==> google-cloud-sdk-492.0.0.tgz: google-cloud-sdk/lib/surface/policy_intelligence/simulate/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command group for Policy Intelligence Simulate."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class SimulateAlpha(base.Group):
  """Simulate changes to Organization Policies."""
  detailed_help = {
      'DESCRIPTION': """\
          Simulate Org policies.

          More information can be found here:
          https://cloud.google.com/iam/docs.
      """
  }


@base.ReleaseTracks(base.ReleaseTrack.BETA)
class SimulateBeta(base.Group):
  """Simulate changes to Organization Policies."""
  detailed_help = {
      'DESCRIPTION': """\
          Simulate Org policies.

          More information can be found here:
          https://cloud.google.com/iam/docs.
      """
  }


@base.ReleaseTracks(base.ReleaseTrack.GA)
@base.Hidden
class SimulateGA(base.Group):
  """Simulate changes to Organization Policies."""
  detailed_help = {
      'DESCRIPTION': """\
          Simulate Org policies.

          More information can be found here:
          https://cloud.google.com/iam/docs.
      """
  }

==> google-cloud-sdk-541.0.0.tgz: google-cloud-sdk/lib/surface/policy_intelligence/simulate/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command group for Policy Intelligence Simulate."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@base.DefaultUniverseOnly
class SimulateAlpha(base.Group):
  """Simulate changes to organization policies."""
  detailed_help = {
      'DESCRIPTION': """\
          Simulate changes to organization policies.
      """
  }


@base.ReleaseTracks(base.ReleaseTrack.BETA)
@base.DefaultUniverseOnly
class SimulateBeta(base.Group):
  """Simulate changes to organization policies."""
  detailed_help = {
      'DESCRIPTION': """\
          Simulate changes to organization policies.
      """
  }


@base.ReleaseTracks(base.ReleaseTrack.GA)
@base.DefaultUniverseOnly
class SimulateGA(base.Group):
  """Simulate changes to organization policies."""
  detailed_help = {
      'DESCRIPTION': """\
          Simulate changes to organization policies.
      """
  }
